extern crate tokio;
extern crate reqwest;
extern crate tide;
extern crate anyhow;
//extern crate sea_orm;

mod state;
mod route;
mod stop;

use tide::prelude::*;

#[tokio::main]
async fn main() -> anyhow::Result<()> {
    let mut app = tide::with_state(state::State::new().await?);

    app.at("/path").get(transit_path);
    app.at("/time_to_arrive").get(transit_estimate);
    app.at("/route_draw").get(bus_route_draw);

    // TODO: change to 0.0.0.0 when docker image done
    app.listen("127.0.0.1:8080").await?;
    Ok(())
}


/// return the best path of buses with the request specifying ISO time, lat and longitude in query params
/// Example return
/// {
///     "path": [
///         {
///             "route_name": "WS Outbound",
///             "enter_stop_id": 3,
///             "exit_stop_id": 10,
///             "enter_stop_coords": {"lat":23.3512, "lon": 1231.123123}
///         },
///         ...
///     ]
/// }
async fn transit_path(mut req: tide::Request<state::State>)->tide::Result{
    Ok("".into())
}

/// return the num of estimated seconds for stop ids given in query params
/// example return:
/// 23
async fn transit_estimate(mut req: tide::Request<state::State>)->tide::Result{
    Ok("".into())
}

/// return the coord pairs as json and line color forgiven route id in query params
/// Example return:
/// {"color":"#0000ff", "stops":[[-75,23],[-21,72]]}
async fn bus_route_draw(mut req: tide::Request<state::State>)->tide::Result{
    match req.query::<RouteDrawQuery>()?.id.split("_").collect::<Vec<&str>>()[..] {
        ["OCCT", id] => {
            let route = route::occt_route_get(id.parse());
        },
        ["BC", id] => {
            let route = route::broome_county_route_get(id.parse());
        },
        _ => {
            return Ok(tide::Response::builder(400).body("Error: invalid id").into())
        }
        
    }
    Ok("".into())
}

#[derive(serde::Deserialize)]
struct RouteDrawQuery{
    id: String
}

